@@ -177,13 +177,7 @@ mod test {
             let optimistic_slots = vec![(1, bad_bank_hash), (3, Hash::default())];
             optimistic_confirmation_verifier.add_new_optimistic_confirmed_slots(optimistic_slots);
             let vote_simulator = setup_forks();
-            let bank1 = vote_simulator
-                .bank_forks
-                .read()
-                .unwrap()
-                .get(1)
-                .cloned()
-                .unwrap();
+            let bank1 = vote_simulator.bank_forks.read().unwrap().get(1).unwrap();
             assert_eq!(
                 optimistic_confirmation_verifier
                     .verify_for_unrooted_optimistic_slots(&bank1, &blockstore),
@@ -225,13 +219,7 @@ mod test {
             // If root is on same fork, nothing should be returned
             optimistic_confirmation_verifier
                 .add_new_optimistic_confirmed_slots(optimistic_slots.clone());
-            let bank5 = vote_simulator
-                .bank_forks
-                .read()
-                .unwrap()
-                .get(5)
-                .cloned()
-                .unwrap();
+            let bank5 = vote_simulator.bank_forks.read().unwrap().get(5).unwrap();
             assert!(optimistic_confirmation_verifier
                 .verify_for_unrooted_optimistic_slots(&bank5, &blockstore)
                 .is_empty());
@@ -241,13 +229,7 @@ mod test {
             // If root is on same fork, nothing should be returned
             optimistic_confirmation_verifier
                 .add_new_optimistic_confirmed_slots(optimistic_slots.clone());
-            let bank3 = vote_simulator
-                .bank_forks
-                .read()
-                .unwrap()
-                .get(3)
-                .cloned()
-                .unwrap();
+            let bank3 = vote_simulator.bank_forks.read().unwrap().get(3).unwrap();
             assert!(optimistic_confirmation_verifier
                 .verify_for_unrooted_optimistic_slots(&bank3, &blockstore)
                 .is_empty());
@@ -261,13 +243,7 @@ mod test {
             // be returned
             optimistic_confirmation_verifier
                 .add_new_optimistic_confirmed_slots(optimistic_slots.clone());
-            let bank4 = vote_simulator
-                .bank_forks
-                .read()
-                .unwrap()
-                .get(4)
-                .cloned()
-                .unwrap();
+            let bank4 = vote_simulator.bank_forks.read().unwrap().get(4).unwrap();
             assert_eq!(
                 optimistic_confirmation_verifier
                     .verify_for_unrooted_optimistic_slots(&bank4, &blockstore),
@@ -283,25 +259,13 @@ mod test {
             vote_simulator.set_root(5);
 
             // Add a new bank 7 that descends from 6
-            let bank6 = vote_simulator
-                .bank_forks
-                .read()
-                .unwrap()
-                .get(6)
-                .cloned()
-                .unwrap();
+            let bank6 = vote_simulator.bank_forks.read().unwrap().get(6).unwrap();
             vote_simulator
                 .bank_forks
                 .write()
                 .unwrap()
                 .insert(Bank::new_from_parent(&bank6, &Pubkey::default(), 7));
-            let bank7 = vote_simulator
-                .bank_forks
-                .read()
-                .unwrap()
-                .get(7)
-                .unwrap()
-                .clone();
+            let bank7 = vote_simulator.bank_forks.read().unwrap().get(7).unwrap();
             assert!(!bank7.ancestors.contains_key(&3));
 
             // Should return slots 1, 3 as part of the rooted fork because there's no
