@@ -1,12 +1,11 @@
 use {
     crate::{cluster_info_vote_listener::VerifiedLabelVotePacketsReceiver, result::Result},
     solana_perf::packet::PacketBatch,
-    solana_runtime::bank::Bank,
+    solana_runtime::{bank::Bank, vote_transaction::VoteTransaction},
     solana_sdk::{
         account::from_account, clock::Slot, hash::Hash, pubkey::Pubkey, signature::Signature,
         slot_hashes::SlotHashes, sysvar,
     },
-    solana_vote_program::vote_state::Vote,
     std::{
         collections::{BTreeMap, HashMap, HashSet},
         sync::Arc,
@@ -18,7 +17,7 @@ const MAX_VOTES_PER_VALIDATOR: usize = 1000;
 
 pub struct VerifiedVoteMetadata {
     pub vote_account_key: Pubkey,
-    pub vote: Vote,
+    pub vote: VoteTransaction,
     pub packet_batch: PacketBatch,
     pub signature: Signature,
 }
@@ -152,15 +151,15 @@ impl VerifiedVotePackets {
                         packet_batch,
                         signature,
                     } = verfied_vote_metadata;
-                    if vote.slots.is_empty() {
+                    if vote.is_empty() {
                         error!("Empty votes should have been filtered out earlier in the pipeline");
                         continue;
                     }
-                    let slot = vote.slots.last().unwrap();
-                    let hash = vote.hash;
+                    let slot = vote.last_voted_slot().unwrap();
+                    let hash = vote.hash();
 
                     let validator_votes = self.0.entry(vote_account_key).or_default();
-                    validator_votes.insert((*slot, hash), (packet_batch, signature));
+                    validator_votes.insert((slot, hash), (packet_batch, signature));
 
                     if validator_votes.len() > MAX_VOTES_PER_VALIDATOR {
                         let smallest_key = validator_votes.keys().next().cloned().unwrap();
@@ -181,6 +180,7 @@ mod tests {
         crossbeam_channel::unbounded,
         solana_perf::packet::Packet,
         solana_sdk::slot_hashes::MAX_ENTRIES,
+        solana_vote_program::vote_state::Vote,
     };
 
     #[test]
@@ -197,7 +197,7 @@ mod tests {
         let vote = Vote::new(vec![vote_slot], vote_hash);
         s.send(vec![VerifiedVoteMetadata {
             vote_account_key,
-            vote: vote.clone(),
+            vote: VoteTransaction::from(vote.clone()),
             packet_batch: PacketBatch::default(),
             signature: Signature::new(&[1u8; 64]),
         }])
@@ -217,7 +217,7 @@ mod tests {
         // Same slot, same hash, should not be inserted
         s.send(vec![VerifiedVoteMetadata {
             vote_account_key,
-            vote,
+            vote: VoteTransaction::from(vote),
             packet_batch: PacketBatch::default(),
             signature: Signature::new(&[1u8; 64]),
         }])
@@ -239,7 +239,7 @@ mod tests {
         let vote = Vote::new(vec![vote_slot], new_vote_hash);
         s.send(vec![VerifiedVoteMetadata {
             vote_account_key,
-            vote,
+            vote: VoteTransaction::from(vote),
             packet_batch: PacketBatch::default(),
             signature: Signature::new(&[1u8; 64]),
         }])
@@ -262,7 +262,7 @@ mod tests {
         let vote = Vote::new(vec![vote_slot], vote_hash);
         s.send(vec![VerifiedVoteMetadata {
             vote_account_key,
-            vote,
+            vote: VoteTransaction::from(vote),
             packet_batch: PacketBatch::default(),
             signature: Signature::new(&[2u8; 64]),
         }])
@@ -282,7 +282,7 @@ mod tests {
         // No new messages, should time out
         assert_matches!(
             verified_vote_packets.receive_and_process_vote_packets(&r, true),
-            Err(Error::CrossbeamRecvTimeout(_))
+            Err(Error::RecvTimeout(_))
         );
     }
 
@@ -301,7 +301,7 @@ mod tests {
             let vote = Vote::new(vec![vote_slot], vote_hash);
             s.send(vec![VerifiedVoteMetadata {
                 vote_account_key,
-                vote,
+                vote: VoteTransaction::from(vote),
                 packet_batch: PacketBatch::default(),
                 signature: Signature::new(&[1u8; 64]),
             }])
@@ -338,7 +338,7 @@ mod tests {
             let vote = Vote::new(vec![vote_slot], vote_hash);
             s.send(vec![VerifiedVoteMetadata {
                 vote_account_key,
-                vote,
+                vote: VoteTransaction::from(vote),
                 packet_batch: PacketBatch::default(),
                 signature: Signature::new_unique(),
             }])
@@ -392,7 +392,7 @@ mod tests {
                 let vote = Vote::new(vec![*vote_slot], *vote_hash);
                 s.send(vec![VerifiedVoteMetadata {
                     vote_account_key,
-                    vote,
+                    vote: VoteTransaction::from(vote),
                     packet_batch: PacketBatch::new(vec![Packet::default(); num_packets]),
                     signature: Signature::new_unique(),
                 }])
@@ -456,7 +456,7 @@ mod tests {
             my_leader_bank.slot() + 1,
         ));
         let vote_account_key = vote_simulator.vote_pubkeys[1];
-        let vote = Vote::new(vec![vote_slot], vote_hash);
+        let vote = VoteTransaction::from(Vote::new(vec![vote_slot], vote_hash));
         s.send(vec![VerifiedVoteMetadata {
             vote_account_key,
             vote,
